@@ -4,6 +4,8 @@ from os.path import join as opj
 import subprocess
 import sys
 
+VERSION = '0.2.2'
+
 class UnmetDependency(OSError):
     pass
 
@@ -27,8 +29,11 @@ def qdiff(left, right):
     os.chdir(left)
     call('bzr', 'init', '-q')
     call('bzr', 'add', '-q')
-    # Set dummy identity in case bzr is not configured
-    call('bzr', 'whoami', '-d', '.', '"Your Name <name@example.com>"')
+    try:
+        call('bzr', 'config', 'email')
+    except CallError:
+        # Set dummy identity in case bzr is not configured
+        call('bzr', 'whoami', '-d', '.', '"Your Name <name@example.com>"')
     call('bzr', 'commit', '-qmm', '--unchanged')
     call('rsync', '-qavLt', '--delete', '--exclude=/.bzr', right, left)
     call('bzr', 'add', '-q')
@@ -60,6 +65,9 @@ def check_dependencies():
         raise UnmetDependency("Could not find `rsync` program")
 
 def main():
+    if len(sys.argv) > 1 and sys.argv[1] == '--version':
+        print("git-qdiff %s" % VERSION)
+        sys.exit()
     try:
         check_dependencies()
     except Exception as e:
@@ -71,6 +79,8 @@ def main():
                 qdiff(left, right)
             except Exception as e:
                 sys.exit(str(e))
+            except KeyboardInterrupt:
+                pass
             sys.exit(0)
 
     # TODO: ensure infinite subcalls is not possible
@@ -81,3 +91,5 @@ def main():
     except subprocess.CalledProcessError as e:
         sys.stderr.write(str(e))
         sys.exit(e.returncode)
+    except KeyboardInterrupt:
+        sys.exit(0)
